Outil d'ajout de tableau

Outil d'ajout de tableau | Table des matières

L'outil d'ajout de tableau ouvre la fenêtre ci-dessous. Elle vous permet de créer dfes talbeaux.
Description des champs:

Colonnes | Nombre de colonnes du tableau.
Lignes | Nombre de lignes du tableau.
Cellpadding | Marge à l'intérieur des cellules du tableau.
Cellspacing | Espacement entre les cellules du tableau.
Alignement | Alignement du tableau.
Bordure | Épaisseur des bordures du tableau.
Largeur | Largeur en pixel du tableau.
Hauteur | Hauteur en pixel du tableau.
Classe CSS | Nom de la classe CSS pour appliquer un style.

Aller à: Table des matières | Haut de page